@@ -18,8 +18,8 @@ sub index {
     my $class = shift;
     my $index = [
         'US::Google', 'US::Yahoo', 'US::Aol', 'US::Outlook', 'US::AmazonSES', 
-        'US::SendGrid', 'US::Verizon', 'RU::MailRu', 'RU::Yandex', 'DE::GMX', 
-        'US::Bigfoot', 'US::Facebook', 'US::Zoho', 'DE::EinsUndEins',
+        'US::SendGrid', 'US::GSuite', 'US::Verizon', 'RU::MailRu', 'RU::Yandex',
+        'DE::GMX', 'US::Bigfoot', 'US::Facebook', 'US::Zoho', 'DE::EinsUndEins',
         'UK::MessageLabs', 'JP::EZweb', 'JP::KDDI', 'JP::Biglobe',
         'US::ReceivingSES', 'US::AmazonWorkMail', 'US::Office365',
     ];
